@@ -32,13 +32,41 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 import pygame
 import pygame_menu.controls as _controls
-from pygame_menu.utils import check_key_pressed_valid
+from pygame_menu.utils import check_key_pressed_valid, to_string
 from pygame_menu.widgets.core import Widget
 
 
+def _check_elements(elements):
+    """
+    Check the element list.
+
+    :param elements: Element list
+    :type elements: list
+    :return: None
+    """
+    assert len(elements) > 0, 'item list (elements) cannot be empty'
+    for e in elements:
+        assert len(e) >= 1, \
+            'length of each element on item list must be greater or equal to 1'
+        assert isinstance(e[0], (str, bytes)), \
+            'first element of each item on list must be a string (the title of each item)'
+
+
 class Selector(Widget):
     """
-    Selector widget.
+    Selector widget: several items with values and
+    two functions that are executed when changing the selector (left/right)
+    and pressing return button on the selected item.
+
+    The values of the selector are like::
+
+        values = [('Item1', a, b, c...), ('Item2', d, e, f..)]
+
+    The callbacks receive the current text, its index in the list,
+    the associated arguments and all unknown keyword arguments::
+
+        onchange((current_text, index), a, b, c..., **kwargs)
+        onreturn((current_text, index), a, b, c..., **kwargs)
 
     :param title: Selector title
     :type title: str
@@ -65,23 +93,19 @@ class Selector(Widget):
                  onreturn=None,
                  *args,
                  **kwargs):
-        assert isinstance(title, str)
         assert isinstance(elements, list)
         assert isinstance(selector_id, str)
         assert isinstance(default, int)
 
         # Check element list
-        for vl in elements:
-            assert len(vl) >= 1, \
-                'Length of each element on item list must be greater or equal to 1'
-            assert isinstance(vl[0], str), \
-                'First element of each item on list must be a string (the title of each item)'
+        _check_elements(elements)
+        assert default >= 0, 'default position must be greater or equal than zero'
         assert default < len(elements), 'default position should be lower than number of values'
         assert isinstance(selector_id, str), 'ID must be a string'
         assert isinstance(default, int), 'default must be an integer'
 
         super(Selector, self).__init__(
-            title=title,
+            title=to_string(title, strict=True),  # Cannot use unicode in py2 as selector use format
             widget_id=selector_id,
             onchange=onchange,
             onreturn=onreturn,
@@ -215,7 +239,6 @@ class Selector(Widget):
                     topright, _ = self._rect.topright
                     dist = mousex - (topleft + self._title_size)  # Distance from label
                     if dist > 0:  # User clicked the options, not label
-
                         # Position in percentage, if <0.5 user clicked left
                         pos = dist / float(topright - topleft - self._title_size)
                         if pos <= 0.5:
@@ -234,9 +257,7 @@ class Selector(Widget):
         :type elements: Object
         :return: None
         """
-        for elem in elements:  # Check value list
-            assert len(elem) >= 1, 'length of each element in value list must be greater than 1'
-            assert isinstance(elem[0], str), 'first element of value list component must be a string'
+        _check_elements(elements)
         selected_element = self._elements[self._index]
         self._elements = elements
         try:
